betty.project.generate package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.generate package

## Submodules

- betty.project.generate.file module
  - `create_file()`
  - `create_html_resource()`
  - `create_json_resource()`

## Module contents

Provide the Generation API.

class betty.project.generate.GenerateSiteEvent

  Bases: `ProjectEvent`

  Dispatched to generate (part of) a project’s site.

async betty.project.generate.generate(project: Project) → None

  Generate a new site.